@@ -4,4 +4,4 @@ from __future__ import annotations
 from executable.cli import cli
 
 if __name__ == "__main__":
-    raise SystemExit(cli())
+    cli()
